@@ -33,9 +33,9 @@
 #include "warn.hh"
 
 LY_DEFINE (ly_parse_file, "ly:parse-file",
-	   1, 0, 0, (SCM name),
-	   "Parse a single @code{.ly} file."
-	   "  Upon failure, throw @code{ly-file-failed} key.")
+           1, 0, 0, (SCM name),
+           "Parse a single @code{.ly} file."
+           "  Upon failure, throw @code{ly-file-failed} key.")
 {
   LY_ASSERT_TYPE (scm_is_string, name, 1);
   string file = ly_scm2string (name);
@@ -51,9 +51,10 @@ LY_DEFINE (ly_parse_file, "ly:parse-file",
   out_file_name.ext_ = "";
   out_file_name.root_ = "";
   if (ly_get_option (ly_symbol2scm ("gui")) != SCM_BOOL_T
-      && ly_get_option (ly_symbol2scm ("strip-output-dir")) == SCM_BOOL_T) {
-    out_file_name.dir_ = "";
-  }
+      && ly_get_option (ly_symbol2scm ("strip-output-dir")) == SCM_BOOL_T)
+    {
+      out_file_name.dir_ = "";
+    }
 
   /* When running from gui, generate output in .ly source directory.  */
   string output_name = output_name_global;
@@ -62,29 +63,29 @@ LY_DEFINE (ly_parse_file, "ly:parse-file",
       /* Interpret --output=DIR to mean --output=DIR/BASE.  */
       string dir;
       if (is_dir (output_name))
-	{
-	  dir = output_name;
-	  output_name = "";
-	}
+        {
+          dir = output_name;
+          output_name = "";
+        }
       else
-	{
-	  File_name out (output_name);
-	  if (is_dir (out.dir_part ()))
-	    {
-	      dir = out.dir_part ();
-	      out_file_name = out.file_part ();
-	    }
-	}
+        {
+          File_name out (output_name);
+          if (is_dir (out.dir_part ()))
+            {
+              dir = out.dir_part ();
+              out_file_name = out.file_part ();
+            }
+        }
 
       if (dir != "" && dir != "." && dir != get_working_directory ())
-	{
-	  global_path.prepend (get_working_directory ());
-	  message (_f ("Changing working directory to: `%s'",
-		       dir.c_str ()));
-	  chdir (dir.c_str ());
-	}
+        {
+          global_path.prepend (get_working_directory ());
+          message (_f ("Changing working directory to: `%s'",
+                       dir.c_str ()));
+          chdir (dir.c_str ());
+        }
       else
-	out_file_name = File_name (output_name);
+        out_file_name = File_name (output_name);
     }
 
   string init;
@@ -98,11 +99,10 @@ LY_DEFINE (ly_parse_file, "ly:parse-file",
     {
       warning (_f ("cannot find init file: `%s'", init));
       warning (_f ("(search path: `%s')",
-		   global_path.to_string ().c_str ()));
+                   global_path.to_string ().c_str ()));
       exit (2);
     }
 
-
   bool error = false;
   if ((file_name != "-") && file_name.empty ())
     {
@@ -134,23 +134,22 @@ LY_DEFINE (ly_parse_file, "ly:parse-file",
   if (error)
     /* TODO: pass renamed input file too.  */
     scm_throw (ly_symbol2scm ("ly-file-failed"),
-	       scm_list_1 (ly_string2scm (file_name)));
+               scm_list_1 (ly_string2scm (file_name)));
 
   return SCM_UNSPECIFIED;
 }
 
-
 LY_DEFINE (ly_parser_lexer, "ly:parser-lexer",
-	   1, 0, 0, (SCM parser_smob),
-	   "Return the lexer for @var{parser-smob}.")
+           1, 0, 0, (SCM parser_smob),
+           "Return the lexer for @var{parser-smob}.")
 {
   Lily_parser *parser = unsmob_lily_parser (parser_smob);
   return parser->lexer_->self_scm ();
 }
 
 LY_DEFINE (ly_parser_clone, "ly:parser-clone",
-	   1, 0, 0, (SCM parser_smob),
-	   "Return a clone of @var{parser-smob}.")
+           1, 0, 0, (SCM parser_smob),
+           "Return a clone of @var{parser-smob}.")
 {
   LY_ASSERT_SMOB (Lily_parser, parser_smob, 1);
   Lily_parser *parser = unsmob_lily_parser (parser_smob);
@@ -160,8 +159,8 @@ LY_DEFINE (ly_parser_clone, "ly:parser-clone",
 }
 
 LY_DEFINE (ly_parser_define_x, "ly:parser-define!",
-	   3, 0, 0, (SCM parser_smob, SCM symbol, SCM val),
-	   "Bind @var{symbol} to @var{val} in @var{parser-smob}'s module.")
+           3, 0, 0, (SCM parser_smob, SCM symbol, SCM val),
+           "Bind @var{symbol} to @var{val} in @var{parser-smob}'s module.")
 {
 
   LY_ASSERT_SMOB (Lily_parser, parser_smob, 1);
@@ -174,9 +173,9 @@ LY_DEFINE (ly_parser_define_x, "ly:parser-define!",
 }
 
 LY_DEFINE (ly_parser_lookup, "ly:parser-lookup",
-	   2, 0, 0, (SCM parser_smob, SCM symbol),
-	   "Look up @var{symbol} in @var{parser-smob}'s module."
-	   "  Return @code{'()} if not defined.")
+           2, 0, 0, (SCM parser_smob, SCM symbol),
+           "Look up @var{symbol} in @var{parser-smob}'s module."
+           "  Return @code{'()} if not defined.")
 {
   LY_ASSERT_SMOB (Lily_parser, parser_smob, 1);
 
@@ -192,9 +191,9 @@ LY_DEFINE (ly_parser_lookup, "ly:parser-lookup",
 }
 
 LY_DEFINE (ly_parser_parse_string, "ly:parser-parse-string",
-	   2, 0, 0, (SCM parser_smob, SCM ly_code),
-	   "Parse the string @var{ly-code} with @var{parser-smob}."
-	   "  Upon failure, throw @code{ly-file-failed} key.")
+           2, 0, 0, (SCM parser_smob, SCM ly_code),
+           "Parse the string @var{ly-code} with @var{parser-smob}."
+           "  Upon failure, throw @code{ly-file-failed} key.")
 {
   LY_ASSERT_SMOB (Lily_parser, parser_smob, 1);
   Lily_parser *parser = unsmob_lily_parser (parser_smob);
@@ -202,7 +201,7 @@ LY_DEFINE (ly_parser_parse_string, "ly:parser-parse-string",
 
   if (!parser->lexer_->is_clean ())
     parser->parser_error (_ ("ly:parser-parse-string is only valid with a new parser."
-			     "  Use ly:parser-include-string instead."));
+                             "  Use ly:parser-include-string instead."));
   else
     parser->parse_string (ly_scm2string (ly_code));
 
@@ -210,9 +209,9 @@ LY_DEFINE (ly_parser_parse_string, "ly:parser-parse-string",
 }
 
 LY_DEFINE (ly_parser_include_string, "ly:parser-include-string",
-	   2, 0, 0, (SCM parser_smob, SCM ly_code),
-	   "Include the string @var{ly-code} into the input stream"
-	   " for @var{parser-smob}.")
+           2, 0, 0, (SCM parser_smob, SCM ly_code),
+           "Include the string @var{ly-code} into the input stream"
+           " for @var{parser-smob}.")
 {
   LY_ASSERT_SMOB (Lily_parser, parser_smob, 1);
   Lily_parser *parser = unsmob_lily_parser (parser_smob);
@@ -224,10 +223,10 @@ LY_DEFINE (ly_parser_include_string, "ly:parser-include-string",
 }
 
 LY_DEFINE (ly_parser_set_note_names, "ly:parser-set-note-names",
-	   2, 0, 0, (SCM parser, SCM names),
-	   "Replace current note names in @var{parser}."
-	   "  @var{names} is an alist of symbols.  This only has effect"
-	   " if the current mode is notes.")
+           2, 0, 0, (SCM parser, SCM names),
+           "Replace current note names in @var{parser}."
+           "  @var{names} is an alist of symbols.  This only has effect"
+           " if the current mode is notes.")
 {
   LY_ASSERT_SMOB (Lily_parser, parser, 1);
   Lily_parser *p = unsmob_lily_parser (parser);
@@ -268,8 +267,8 @@ LY_DEFINE (ly_parser_set_repetition_function, "ly:parser-set-repetition-function
 }
 
 LY_DEFINE (ly_parser_output_name, "ly:parser-output-name",
-	   1, 0, 0, (SCM parser),
-	   "Return the base name of the output file.")
+           1, 0, 0, (SCM parser),
+           "Return the base name of the output file.")
 {
   LY_ASSERT_SMOB (Lily_parser, parser, 1);
   Lily_parser *p = unsmob_lily_parser (parser);
@@ -278,8 +277,8 @@ LY_DEFINE (ly_parser_output_name, "ly:parser-output-name",
 }
 
 LY_DEFINE (ly_parser_error, "ly:parser-error",
-	   2, 1, 0, (SCM parser, SCM msg, SCM input),
-	   "Display an error message and make the parser fail.")
+           2, 1, 0, (SCM parser, SCM msg, SCM input),
+           "Display an error message and make the parser fail.")
 {
   LY_ASSERT_SMOB (Lily_parser, parser, 1);
   Lily_parser *p = unsmob_lily_parser (parser);
@@ -297,13 +296,12 @@ LY_DEFINE (ly_parser_error, "ly:parser-error",
 }
 
 LY_DEFINE (ly_parser_clear_error, "ly:parser-clear-error",
-	   1, 0, 0, (SCM parser),
-	   "Clear the error flag for the parser.")
+           1, 0, 0, (SCM parser),
+           "Clear the error flag for the parser.")
 {
   LY_ASSERT_SMOB (Lily_parser, parser, 1);
   Lily_parser *p = unsmob_lily_parser (parser);
 
-
   p->error_level_ = 0;
   p->lexer_->error_level_ = 0;
 
@@ -311,8 +309,8 @@ LY_DEFINE (ly_parser_clear_error, "ly:parser-clear-error",
 }
 
 LY_DEFINE (ly_parser_has_error_p, "ly:parser-has-error?",
-	   1, 0, 0, (SCM parser),
-	   "Does @var{parser} have an error flag?")
+           1, 0, 0, (SCM parser),
+           "Does @var{parser} have an error flag?")
 {
   LY_ASSERT_SMOB (Lily_parser, parser, 1);
   Lily_parser *p = unsmob_lily_parser (parser);
