@@ -30,7 +30,6 @@
 
 #include "translator.icc"
 
-
 /*
   NOTE NOTE NOTE
 
@@ -38,7 +37,7 @@
   apply there too.
 
   (on principle, engravers don't use inheritance for code sharing)
-  
+
  */
 
 /*
@@ -48,10 +47,10 @@
 */
 class Slur_engraver : public Engraver
 {
-  Drul_array<Stream_event *> events_;
-  Stream_event *running_slur_start_;
-  vector<Grob*> slurs_;
-  vector<Grob*> end_slurs_;
+  vector<Stream_event *> start_events_;
+  vector<Stream_event *> stop_events_;
+  vector<Grob *> slurs_;
+  vector<Grob *> end_slurs_;
 
   void set_melisma (bool);
 
@@ -71,14 +70,12 @@ protected:
 
   virtual void finalize ();
 
-
 public:
   TRANSLATOR_DECLARATIONS (Slur_engraver);
 };
 
 Slur_engraver::Slur_engraver ()
 {
-  events_[START] = events_[STOP] = 0;
 }
 
 IMPLEMENT_TRANSLATOR_LISTENER (Slur_engraver, slur);
@@ -87,11 +84,11 @@ Slur_engraver::listen_slur (Stream_event *ev)
 {
   Direction d = to_dir (ev->get_property ("span-direction"));
   if (d == START)
-    ASSIGN_EVENT_ONCE (events_[START], ev);
+    start_events_.push_back (ev);
   else if (d == STOP)
-    ASSIGN_EVENT_ONCE (events_[STOP], ev);
+    stop_events_.push_back (ev);
   else ev->origin ()->warning (_f ("direction of %s invalid: %d",
-				   "slur-event", int (d)));
+                                     "slur-event", int (d)));
 }
 
 void
@@ -134,7 +131,6 @@ Slur_engraver::acknowledge_tuplet_number (Grob_info info)
   acknowledge_extra_object (info);
 }
 
-
 void
 Slur_engraver::acknowledge_script (Grob_info info)
 {
@@ -157,47 +153,71 @@ Slur_engraver::acknowledge_tie (Grob_info info)
 void
 Slur_engraver::finalize ()
 {
-  if (slurs_.size ())
+  for (vsize i = 0; i < slurs_.size (); i++)
     {
-      slurs_[0]->warning (_ ("unterminated slur"));
-      for (vsize i = 0; i < slurs_.size (); i++)
-	slurs_[i]->suicide ();
+      slurs_[i]->warning (_ ("unterminated slur"));
+      slurs_[i]->suicide ();
     }
 }
 
 void
 Slur_engraver::process_music ()
 {
-  if (events_[STOP])
+  for (vsize i = 0; i < stop_events_.size (); i++)
     {
-      if (slurs_.size () == 0)
-	events_[STOP]->origin ()->warning (_ ("cannot end slur"));
+      Stream_event *ev = stop_events_[i];
+      string id = robust_scm2string (ev->get_property ("spanner-id"), "");
 
-      
-      end_slurs_ = slurs_;
-      slurs_.clear ();
+      // Find the slur that is ended with this event (by checking the spanner-id)
+      bool ended = false;
+      for (vsize j = slurs_.size (); j--;)
+        {
+          if (id == robust_scm2string (slurs_[j]->get_property ("spanner-id"), ""))
+            {
+              ended = true;
+              end_slurs_.push_back (slurs_[j]);
+              slurs_.erase (slurs_.begin () + j);
+            }
+        }
+      if (!ended)
+        ev->origin ()->warning (_ ("cannot end slur"));
     }
 
-  if (events_[START] && slurs_.empty ())
+  for (vsize i = start_events_.size (); i--;)
     {
-      Stream_event *ev = events_[START];
+      Stream_event *ev = start_events_[i];
+      string id = robust_scm2string (ev->get_property ("spanner-id"), "");
+      bool have_slur = false;
+      // Check if we already have a slur with the same spanner-id.
+      // In that case, don't create a new slur, but print a warning
+      for (vsize j = 0; j < slurs_.size (); j++)
+        have_slur = have_slur || (id == robust_scm2string (slurs_[j]->get_property ("spanner-id"), ""));
 
-      bool double_slurs = to_boolean (get_property ("doubleSlurs"));
+      if (have_slur)
+        {
+          // We already have a slur, so give a warning and completely ignore
+          // the new slur.
+          ev->origin ()->warning (_ ("already have slur"));
+          start_events_.erase (start_events_.begin () + i);
+        }
+      else
+        {
+          Grob *slur = make_spanner ("Slur", ev->self_scm ());
+          Direction updown = to_dir (ev->get_property ("direction"));
+          slur->set_property ("spanner-id", ly_string2scm (id));
+          if (updown)
+            set_grob_direction (slur, updown);
+          slurs_.push_back (slur);
 
-      Grob *slur = make_spanner ("Slur", events_[START]->self_scm ());
-      Direction updown = to_dir (ev->get_property ("direction"));
-      if (updown && !double_slurs)
-	set_grob_direction (slur, updown);
-
-      slurs_.push_back (slur);
-
-      if (double_slurs)
-	{
-	  set_grob_direction (slur, DOWN);
-	  slur = make_spanner ("Slur", events_[START]->self_scm ());
-	  set_grob_direction (slur, UP);
-	  slurs_.push_back (slur);
-	}
+          if (to_boolean (get_property ("doubleSlurs")))
+            {
+              set_grob_direction (slur, DOWN);
+              slur = make_spanner ("Slur", ev->self_scm ());
+              slur->set_property ("spanner-id", ly_string2scm (id));
+              set_grob_direction (slur, UP);
+              slurs_.push_back (slur);
+            }
+        }
     }
   set_melisma (slurs_.size ());
 }
@@ -208,23 +228,23 @@ Slur_engraver::stop_translation_timestep ()
   if (Grob *g = unsmob_grob (get_property ("currentCommandColumn")))
     {
       for (vsize i = 0; i < end_slurs_.size (); i++)
-	Slur::add_extra_encompass (end_slurs_[i], g);
+        Slur::add_extra_encompass (end_slurs_[i], g);
 
-      if (!events_[START])
-	for (vsize i = 0; i < slurs_.size (); i++)
-	  Slur::add_extra_encompass (slurs_[i], g);
+      if (!start_events_.size ())
+        for (vsize i = 0; i < slurs_.size (); i++)
+          Slur::add_extra_encompass (slurs_[i], g);
     }
-  
-  
+
   for (vsize i = 0; i < end_slurs_.size (); i++)
     {
-      Spanner * s = dynamic_cast<Spanner*> (end_slurs_[i]);
+      Spanner *s = dynamic_cast<Spanner *> (end_slurs_[i]);
       if (!s->get_bound (RIGHT))
-	s->set_bound (RIGHT, unsmob_grob (get_property ("currentMusicalColumn")));
+        s->set_bound (RIGHT, unsmob_grob (get_property ("currentMusicalColumn")));
       announce_end_grob (s, SCM_EOL);
     }
   end_slurs_.clear ();
-  events_[START] = events_[STOP] = 0;
+  start_events_.clear ();
+  stop_events_.clear ();
 }
 
 ADD_ACKNOWLEDGER (Slur_engraver, accidental);
@@ -235,16 +255,16 @@ ADD_ACKNOWLEDGER (Slur_engraver, text_script);
 ADD_ACKNOWLEDGER (Slur_engraver, tie);
 ADD_ACKNOWLEDGER (Slur_engraver, tuplet_number);
 ADD_TRANSLATOR (Slur_engraver,
-		/* doc */
-		"Build slur grobs from slur events.",
+                /* doc */
+                "Build slur grobs from slur events.",
 
-		/* create */
-		"Slur ",
+                /* create */
+                "Slur ",
 
-		/* read */
-		"slurMelismaBusy "
-		"doubleSlurs ",
+                /* read */
+                "slurMelismaBusy "
+                "doubleSlurs ",
 
-		/* write */
-		""
-		);
+                /* write */
+                ""
+               );
