@@ -1,6 +1,6 @@
 ;;;; This file is part of LilyPond, the GNU music typesetter.
 ;;;;
-;;;; Copyright (C) 2006--2010 Han-Wen Nienhuys <hanwen@xs4all.nl>
+;;;; Copyright (C) 2006--2011 Han-Wen Nienhuys <hanwen@xs4all.nl>
 ;;;;
 ;;;; LilyPond is free software: you can redistribute it and/or modify
 ;;;; it under the terms of the GNU General Public License as published by
@@ -69,7 +69,7 @@
  (lambda (j)
    (module-define!
     page-module
-    (string->symbol (format "page-~a" j))
+    (string->symbol (format #f "page-~a" j))
     (lambda (pg)
       (page-property pg j))))
 
